@@ -316,7 +316,7 @@ class SolfegeApp(cfg.ConfigUtils):
                 self.handle_href('%s.html' % solfege.win.m_viewer)
     def show_exercise_theory(self):
         if self.m_teachers[self.m_running_exercise].m_P.header.theory:
-            solfege.win.display_docfile("%s.html" % self.m_teachers[self.m_running_exercise].m_P.header.theory, "")
+            solfege.win.display_docfile("%s.html" % self.m_teachers[self.m_running_exercise].m_P.header.theory)
     def _practise_lessonfile(self, filename, urlobj=None):
         """
         return the module name.
