@@ -121,18 +121,18 @@ class SelectWinBase(gtk.ScrolledWindow):
         # because I need to add +2 below to avoid the vertical scrollbar on
         # ubuntu 10.04 and +4 on MS Windows XP.
         h = self.g_box.size_request()[1] + 4
-        if h > gtk.gdk.Screen().get_height() * 0.8:
-            h = gtk.gdk.Screen().get_height() *0.8
+        if h > gtk.gdk.screen_height() * 0.8:
+            h = gtk.gdk.screen_height() *0.8
         self.set_size_request(w, h if h > self.m_min_height else self.m_min_height)
         # Then we check if we have to move the app window higher up on the
         # screen so that the whole window is visible.
         px, py = solfege.win.get_position()
-        if py + h > gtk.gdk.Screen().get_height():
+        if py + h > gtk.gdk.screen_height():
             solfege.win.move(px, 0)
 
 
 class ExerciseView(SelectWinBase):
-    max_exercise_label_width = int(gtk.gdk.Screen().get_width() * 0.90)
+    max_exercise_label_width = int(gtk.gdk.screen_width() * 0.90)
     def __init__(self,  fields=('link',)):
         SelectWinBase.__init__(self)
         self.m_fields = fields
@@ -162,6 +162,13 @@ class ExerciseView(SelectWinBase):
         self.g_hbox = gu.bHBox(self.g_box)
         self.g_hbox.set_spacing(gu.hig.SPACE_MEDIUM)
         label = None
+        do_sg = True
+        if len(page[0]) > 0 and isinstance(page[0][0], frontpage.LinkList):
+            count = 0
+            for p in page[0]:
+                count += len(p[0])
+            if count > 80:
+                do_sg = False
         for column in page:
             sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
             assert isinstance(column, frontpage.Column)
@@ -206,7 +213,8 @@ class ExerciseView(SelectWinBase):
                                     lbl = gu.ClickableLabel(_no_xgettext(labeltxt))
                                     if fieldname == u'link-with-filename-tooltip':
                                         lbl.set_tooltip_text(link)
-                                    sizegroups[fieldname].add_widget(lbl)
+                                    if do_sg:
+                                        sizegroups[fieldname].add_widget(lbl)
                                     if show_topics:
                                         topic = solfege.app.m_frontpage_data.get_topic_of_lesson_file(link)
                                         if topic and topic not in labeltxt:
@@ -218,7 +226,8 @@ class ExerciseView(SelectWinBase):
                                     else:
                                         lbl = gtk.Label(lessonfile.infocache.get(link, fieldname))
                                     lbl.set_alignment(0.0, 0.5)
-                                    sizegroups[fieldname].add_widget(lbl)
+                                    if do_sg:
+                                        sizegroups[fieldname].add_widget(lbl)
                                 label.pack_start(lbl, False)
                         except lessonfile.InfoCache.FileNotFound:
                             label = gu.ClickableLabel(_(u"«%s» was not found") % link)
@@ -249,16 +258,17 @@ class ExerciseView(SelectWinBase):
                                 box.pack_start(gtk.Label(_("passed, %.1f%%") % (result * 100)))
                             if passed == False:
                                 box.pack_start(gtk.Label(_("failed, %.1f%%") % (result * 100)))
-                            # do nothing if passed == None since 
+                            # do nothing if passed == None since
                         linkbox.pack_start(box, True)
                     else:
                         linkbox.pack_start(label, True)
-                    sizegroup.add_widget(label)
+                    if do_sg:
+                        sizegroup.add_widget(label)
             if label:
                 label.set_data('last', True)
         self.g_hbox.show_all()
         self.adjust_scrolledwin_size()
-        self.get_vadjustment().value = 0.0
+        self.get_vadjustment().set_value(0.0)
     def on_page_link_clicked(self, btn, link):
         self.g_searchbox.hide()
         self.display_data(link)
@@ -269,10 +279,10 @@ class ExerciseView(SelectWinBase):
           frontpage.Page(u'',
             frontpage.Column([
               frontpage.LinkList(
-            _("Search results for “%s”:" % self.g_searchentry.get_text()),
+            _(u"Search results for “%s”:") % self.g_searchentry.get_text(),
               result),
               frontpage.LinkList(
-            _("C-locale search results for “%s”:" % self.g_searchentry.get_text()),
+            _(u"C-locale search results for “%s”:") % self.g_searchentry.get_text(),
               result_C),
               ])))
     def on_end_practise(self, w=None):
@@ -296,7 +306,7 @@ class ExerciseView(SelectWinBase):
         page = frontpage.Page(listitems=frontpage.Column())
         cur_topic = None
         # the last topic appended to the page
-        last_topic = None 
+        last_topic = None
         found = set()
         for child in self.m_page.iterate_flattened():
             if isinstance(child, frontpage.LinkList):
@@ -353,7 +363,7 @@ class TestsView(ExerciseView):
 class SearchView(ExerciseView):
     def __init__(self, infotext, fields=('link',)):
         ExerciseView.__init__(self, fields)
-        page = """FileHeader(1, 
+        page = """FileHeader(1,
         Page(u'', [
          Column([
           Paragraph('%s'),
