@@ -38,8 +38,8 @@ class TestScore(unittest.TestCase):
         self.assert_(isinstance(self.score.voice11.m_tdict[Rat(0, 1)]['elem'][0].w_parent(), Stem))
         self.assert_(isinstance(self.score.voice11.m_tdict[Rat(0, 1)]['elem'][0].w_parent().w_parent(), Voice))
         # bar full:
-        self.assertRaises(Voice.BarFullException, lambda: self.score.voice11.append(
-            Note.new_from_string("c'4")))
+        self.assertRaises(Voice.BarFullException, self.score.voice11.append,
+            Note.new_from_string("c'4"))
         self.score.voice11.append(Note.new_from_string("c'8"))
         self.score.voice11.append([
             Note.new_from_string("c'1"),
@@ -66,9 +66,20 @@ class TestScore(unittest.TestCase):
         self.assertEquals(self.score.m_bars[1].m_timesig, TimeSignature(5, 8))
         self.score.add_bar(None)
         self.assertEquals(self.score.m_bars[2].m_timesig, TimeSignature(5, 8))
+    def test_add_partial_bar(self):
+        self.score.add_partial_bar(Duration.new_from_string("4"), TimeSignature(4, 4))
+        self.score.add_bar(None)
+        self.assertEquals(self.score.m_bars[0].m_timepos, Rat(0, 1))
+        self.assertEquals(self.score.m_bars[0].end(), Rat(1, 4))
+        self.assertEquals(self.score.m_bars[1].m_timepos, Rat(1, 4))
+        self.assertEquals(self.score.get_bar_at(Rat(0, 1)), self.score.m_bars[0])
+        self.assertEquals(self.score.get_bar_at(Rat(1, 4)), self.score.m_bars[1])
+        self.score.voice11.append(Note.new_from_string("c4"))
+        self.score.voice11.append(Note.new_from_string("c1"))
+        self.score.voice11.append(Note.new_from_string("c1"))
     def test_get_bar_at(self):
         # Raise exception, since we have not added bars
-        self.assertRaises(IndexError, lambda: self.score.get_bar_at(Rat(0, 1)))
+        self.assertRaises(IndexError, self.score.get_bar_at, Rat(0, 1))
         # None is to get the default timesig 4/4
         self.score.add_bar(None)
         self.assert_(isinstance(self.score.get_bar_at(Rat(0, 1)), Bar))
@@ -90,9 +101,9 @@ class TestScore(unittest.TestCase):
     def test_no_chords_in_rhythm_staff(self):
         self.score.add_staff(RhythmStaff)
         self.score.voice21.append(Note.new_from_string("cis4"))
-        self.assertRaises(Voice.NoChordsInRhythmStaffException, lambda:
-                self.score.voice21.append([Note.new_from_string("gis4"),
-                                           Note.new_from_string("fis4")]))
+        self.assertRaises(Voice.NoChordsInRhythmStaffException,
+                self.score.voice21.append,
+                [Note.new_from_string("gis4"), Note.new_from_string("fis4")])
     def test_is_bar_full(self):
         self.assertTrue(self.score.voice11.is_bar_full())
         self.score.voice11.append(Note.new_from_string("c2"))
@@ -131,6 +142,12 @@ class TestScore(unittest.TestCase):
         self.score.voice11.append(n2)
         self.score.voice11.append(n3)
         self.score.voice11.tuplet(Rat(2, 3), const.UP, [n1, n2, n3])
+    def test_single_tuplet(self):
+        n1 = Note(MusicalPitch.new_from_notename("g'"),
+                  Duration(8, 0, Rat(2, 3)))
+        self.score.voice11.append(n1)
+        self.score.voice11.tuplet(Rat(2, 3), const.UP, [n1])
+        self.assertEquals(n1.w_parent().m_tupletinfo, 'end')
     def test_rh_1(self):
         self.assertEquals(f3(r"\staff{c}"), [[True, Rat(1, 4)]])
         self.assertEquals(f3(r"\staff{c2}"), [[True, Rat(1, 2)]])
@@ -296,6 +313,16 @@ c4 c8 c8
             [Rat(0, 1)])
         self.assertEquals(
             self.score.voice11.get_timeposes_of(self.score.m_bars[1]), [])
+    def test_get_time_pitch_list(self):
+        def f(s, tempo=(60, 4)):
+            s = parser.parse_to_score_object(r"\staff{ %s}" % s)
+            return s.voice11.get_time_pitch_list(tempo)
+        self.assertEquals(f("c4 d4"), [(48, 1.0), (50, 1.0)])
+        self.assertEquals(f("c4 d2"), [(48, 1.0), (50, 2.0)])
+        self.assertEquals(f("c4 d2", (120, 4)), [(48, 0.5), (50, 1.0)])
+        self.assertEquals(f(r" \times 2/3 { c4 d2 }"), [(48, 2.0/3), (50, 4.0/3)])
+        self.assertEquals(f("c4 r8. d4"), [(48, 1.0), (-1, 0.75), (50, 1.0)])
+        self.assertRaises(Voice.NotUnisonException, f, "<c4 d4>")
     def test_is_last(self):
         voice = self.score.voice11
         voice.append(Note.new_from_string("c2"))
@@ -307,6 +334,9 @@ c4 c8 c8
         self.assertTrue(voice.is_last(Rat(1, 2)))
         self.assertTrue(voice.is_last(Rat(1, 1)))
         self.assertFalse(voice.is_last(Rat(2, 1)))
+    def test_partial_bar(self):
+        voice = self.score.voice11
+
 
 class TestNote(unittest.TestCase):
     def setUp(self):
@@ -316,13 +346,12 @@ class TestNote(unittest.TestCase):
         n = Note(MusicalPitch.new_from_notename("c'"),
                  Duration.new_from_string("4."))
         self.assertRaises(AssertionError,
-                          lambda: Note("4.",
-                                       MusicalPitch.new_from_notename("c'")))
+                          Note, "4.", MusicalPitch.new_from_notename("c'"))
         self.assertRaises(AssertionError,
-                          lambda: Note(Duration.new_from_string("4."), "c'"))
+                          Note, Duration.new_from_string("4."), "c'")
     def test_new_from_string(self):
         n = Note.new_from_string("c'4.")
-        self.assertRaises(InvalidNotenameException, lambda: Note.new_from_string("x"))
+        self.assertRaises(InvalidNotenameException, Note.new_from_string, "x")
     def test_beam(self):
         voice = self.score.voice11
         n1 = Note.new_from_string("c'8")
@@ -333,7 +362,7 @@ class TestNote(unittest.TestCase):
         voice2 = self.score.staff1.add_voice()
         n3 = Note.new_from_string("d'8")
         n4 = Note.new_from_string("d'8")
-        self.assertRaises(Voice.NoteDontBelongHere, lambda: voice.beam([n3, n4]))
+        self.assertRaises(Voice.NoteDontBelongHere, voice.beam, [n3, n4])
     def test_tie_2notes(self):
         voice = self.score.voice11
         n1 = Note.new_from_string("c'4")
