@@ -18,7 +18,7 @@ class TestStringGetLineAt(unittest.TestCase):
         self.assertEquals(string_get_line_at("abc\n\n", 4), "")
         self.assertEquals(string_get_line_at("abc\n\nx", 4), "")
         self.assertEquals(string_get_line_at("abc\n\nx", 5), "x")
-        self.assertRaises(IndexError, lambda x: string_get_line_at("", 0), "")
+        self.assertRaises(IndexError, string_get_line_at, "", 0)
         self.assertEquals(string_get_line_at("  \n\n   \t \n \t abc \n", 3), "")
         self.assertEquals(string_get_line_at("  \n\n   \t \n \t abc \n", 4), "   \t ")
 
